@@ -1,15 +1,11 @@
-import datetime
-
 import htmlgenerator as hg
 from django import forms
 from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
 from django.db import models
-from django.utils.dateformat import DateFormat
 from django.utils.translation import gettext_lazy as _
-from jinja2.sandbox import SandboxedEnvironment
 
-from basxbread import layout
+from basxbread import layout, utils
 from basxbread.querysetfield import QuerysetField, parsequeryexpression
 
 from ...layout.components.datatable import DataTableColumn
@@ -133,12 +129,6 @@ class ReportColumn(models.Model):
         ),
     )
     cell_template.formfield_kwargs = {"widget": forms.Textarea(attrs={"rows": 1})}
-    sortingname = models.CharField(
-        _("Sortingname"),
-        max_length=255,
-        blank=True,
-        help_text=_("Django sorting expression"),
-    )
     aggregation = models.CharField(
         _("Aggregation"), max_length=64, choices=tuple(AGGREGATIONS.items()), blank=True
     )
@@ -147,14 +137,14 @@ class ReportColumn(models.Model):
         if self.cell_template:
 
             def render(context):
-                elementenv = SandboxedEnvironment()
-                elementenv.filters["map"] = lambda value, map: map.get(value, value)
                 try:
-                    cellcontent = elementenv.from_string(self.cell_template).render(
-                        value=ensure_localized_date(
-                            hg.resolve_lookup(context[rowvariable], self.column)
-                        ),
-                        object=context[rowvariable],
+                    cellcontent = (
+                        utils.jinja_env()
+                        .from_string(self.cell_template)
+                        .render(
+                            value=hg.resolve_lookup(context[rowvariable], self.column),
+                            object=context[rowvariable],
+                        )
                     )
                     return hg.BaseElement(
                         hg.mark_safe(cellcontent) if self.allow_html else cellcontent
@@ -170,9 +160,3 @@ class ReportColumn(models.Model):
         verbose_name = _("Column")
         verbose_name_plural = _("Columns")
         order_with_respect_to = "report"
-
-
-def ensure_localized_date(value):
-    if isinstance(value, (datetime.datetime, datetime.date)):
-        return DateFormat(value)
-    return value
